=======
aircopy
=======

.. image:: https://img.shields.io/travis/st3107/aircopy.svg
        :target: https://travis-ci.org/st3107/aircopy

.. image:: https://img.shields.io/pypi/v/aircopy.svg
        :target: https://pypi.python.org/pypi/aircopy


The CLI software to copy airtable data to Billinge group database

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://st3107.github.io/aircopy.

Installation
------------

Install pip on your machine. Run the following code in the terminal.

``pip install aircopy``

Usage
-----

Run the following command to find out the usage in the terminal.

``aircopy -- --help``

Features
--------

* TODO
